==> transmission_2.03.orig.tar.bz2: transmission-2.03/macosx/InfoPeersViewController.h <==
/******************************************************************************
 * $Id: InfoPeersViewController.h 10389 2010-03-16 00:45:52Z charles $
 *
 * Copyright (c) 2010 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>
#import "InfoViewController.h"

@interface InfoPeersViewController : NSViewController <InfoViewController>
{
    NSArray * fTorrents;
    
    BOOL fSet;
    
    NSMutableArray * fPeers, * fWebSeeds;
    
    IBOutlet NSTableView * fPeerTable, * fWebSeedTable;
    CGFloat fWebSeedTableHeight, fSpaceBetweenWebSeedAndPeer;
    
    NSViewAnimation * fWebSeedTableAnimation;
    
    IBOutlet NSTextField * fConnectedPeersField;
}

- (void) setInfoForTorrents: (NSArray *) torrents;
- (void) updateInfo;

- (void) saveViewSize;
- (void) clearView;
- (void) stopWebSeedAnimation;

@end

==> transmission_2.42.orig.tar.bz2: transmission-2.42/macosx/InfoPeersViewController.h <==
/******************************************************************************
 * $Id: InfoPeersViewController.h 12686 2011-08-15 00:30:29Z livings124 $
 *
 * Copyright (c) 2010-2011 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>
#import "InfoViewController.h"

@interface InfoPeersViewController : NSViewController <InfoViewController, NSAnimationDelegate>
{
    NSArray * fTorrents;
    
    BOOL fSet;
    
    NSMutableArray * fPeers, * fWebSeeds;
    
    IBOutlet NSTableView * fPeerTable, * fWebSeedTable;
    CGFloat fWebSeedTableHeight, fSpaceBetweenWebSeedAndPeer;
    
    NSViewAnimation * fWebSeedTableAnimation;
    
    IBOutlet NSTextField * fConnectedPeersField;
}

- (void) setInfoForTorrents: (NSArray *) torrents;
- (void) updateInfo;

- (void) saveViewSize;
- (void) clearView;
- (void) stopWebSeedAnimation;

@end
